@@ -38,6 +38,8 @@ if __name__ == '__main__':
     parser.add_argument('-g','--gpu', type=int, default=0)
     parser.add_argument('--max_iteration', type=int, default=30000)
     parser.add_argument('--seed', type=int, default=124)
+    parser.add_argument('--chunk_size', type=int, default=100000)
+    parser.add_argument('--ignore_umap', action='store_true')
 #     parser.add_argument('--beta', type=float, default=0.5)
 #     parser.add_argument('--hid_dim', type=int, default=1024)
 #     parser.add_argument('--eval', action='store_true')
@@ -45,20 +47,24 @@ if __name__ == '__main__':
     args = parser.parse_args()
 
     
-    adata = SCALEX(args.data_list, 
-                   batch_categories=args.batch_categories, 
-                   join=args.join, 
-                   batch_key=args.batch_key, 
-                   min_genes=args.min_genes, 
-                   min_cells=args.min_cells, 
-                   n_top_genes=args.n_top_genes, 
-                   batch_size=args.batch_size, 
-                   lr=args.lr, 
-                   max_iteration=args.max_iteration, 
-                   impute=args.impute,
-                   batch_name=args.batch_name, 
-                   seed=args.seed, 
-                   gpu=args.gpu, 
-                   outdir=args.outdir, 
-                   projection=args.projection, 
-                   save=True)
+    adata = SCALEX(
+        args.data_list, 
+        batch_categories=args.batch_categories, 
+        join=args.join, 
+        batch_key=args.batch_key, 
+        min_genes=args.min_genes, 
+        min_cells=args.min_cells, 
+        n_top_genes=args.n_top_genes, 
+        batch_size=args.batch_size, 
+        lr=args.lr, 
+        max_iteration=args.max_iteration, 
+        impute=args.impute,
+        batch_name=args.batch_name, 
+        seed=args.seed, 
+        gpu=args.gpu, 
+        outdir=args.outdir, 
+        projection=args.projection, 
+        chunk_size=args.chunk_size,
+        ignore_umap=args.ignore_umap,
+        verbose=True
+    )
