@@ -22,23 +22,27 @@ from .logger import create_logger
 from .visualize import plot_umap
 
 
-def SCALEX(data_list, 
-           batch_categories=None, 
-           join='inner', 
-           batch_key='batch', 
-           batch_name='batch',
-           min_genes=600, 
-           min_cells=3, 
-           n_top_genes=2000, 
-           batch_size=64, 
-           lr=2e-4, 
-           max_iteration=30000,
-           seed=124, 
-           gpu=0, 
-           outdir='output/', 
-           projection=None, 
-           impute=None, 
-           save=True):
+def SCALEX(
+        data_list, 
+        batch_categories=None, 
+        join='inner', 
+        batch_key='batch', 
+        batch_name='batch',
+        min_genes=600, 
+        min_cells=3, 
+        n_top_genes=2000, 
+        batch_size=64, 
+        lr=2e-4, 
+        max_iteration=30000,
+        seed=124, 
+        gpu=0, 
+        outdir='output/', 
+        projection=None, 
+        impute=None, 
+        chunk_size=100000,
+        ignore_umap=False,
+        verbose=False,
+    ):
     
     # sc.logging.print_versions()
     np.random.seed(seed) # seed
@@ -55,9 +59,17 @@ def SCALEX(data_list,
         os.makedirs(outdir+'/checkpoint', exist_ok=True)
         log = create_logger('', fh=outdir+'log.txt')
         
-        adata, trainloader, testloader = load_dataset(data_list, batch_categories, 
-                                                      join=join, n_top_genes=n_top_genes,
-                                                      batch_name=batch_name, batch_key=batch_key)
+        adata, trainloader, testloader = load_dataset(
+            data_list, batch_categories, 
+            join=join, 
+            n_top_genes=n_top_genes,
+            batch_size=batch_size, 
+            chunk_size=chunk_size,
+            min_genes=min_genes, 
+            min_cells=min_cells,
+            batch_name=batch_name, 
+            batch_key=batch_key
+        )
         log.info('Processed dataset shape: {}'.format(adata.shape))
         
         early_stopping = EarlyStopping(patience=10, checkpoint_file=outdir+'/checkpoint/model.pt')
@@ -65,13 +77,15 @@ def SCALEX(data_list,
         enc = [['fc', 1024, 1, 'relu'],['fc', 10, '', '']]  # TO DO
         dec = [['fc', x_dim, n_domain, 'sigmoid']]
         model = VAE(enc, dec, n_domain=n_domain)
-        log.info('model\n'+model.__repr__())
-        model.fit(trainloader, testloader=testloader,
-                  lr=lr, 
-                  max_iteration=max_iteration, 
-                  device=device, 
-                  early_stopping=early_stopping, 
-                  log=log)
+#         log.info('model\n'+model.__repr__())
+        model.fit(
+            trainloader, testloader=testloader,
+            lr=lr, 
+            max_iteration=max_iteration, 
+            device=device, 
+            early_stopping=early_stopping, 
+            verbose=verbose,
+        )
         torch.save({'n_top_genes':adata.var.index, 'enc':enc, 'dec':dec, 'n_domain':n_domain}, outdir+'/checkpoint/config.pt')     
     else:
         os.makedirs(outdir, exist_ok=True)
@@ -83,8 +97,15 @@ def SCALEX(data_list,
         model.load_model(projection+'/checkpoint/model.pt')
         model.to(device)
         
-        adata, trainloader, testloader = load_dataset(data_list, batch_categories, join='outer', 
-                                                      n_top_genes=n_top_genes, min_cells=0)
+        adata, trainloader, testloader = load_dataset(
+            data_list, batch_categories, 
+            join='outer', 
+            chunk_size=chunk_size,
+            n_top_genes=n_top_genes, 
+            min_cells=0,
+            batch_name=batch_name,
+            batch_key=batch_key
+        )
         log.info('Processed dataset shape: {}'.format(adata.shape))
         
     adata.obsm['latent'] = model.encodeBatch(testloader, device=device) # save latent rep
@@ -94,15 +115,17 @@ def SCALEX(data_list,
     log.info(outdir)
     if projection:
         ref = sc.read_h5ad(projection+'/adata.h5ad')
-        adata = AnnData.concatenate(ref, adata, batch_categories=['reference', 'query'], 
-                                    batch_key='projection', index_unique=None)
-    
-    sc.pp.neighbors(adata, n_neighbors=30, use_rep='latent')
-    sc.tl.umap(adata, min_dist=0.1)
-    sc.tl.leiden(adata)
-
-    if save:
-        adata.write(outdir+'adata.h5ad', compression='gzip')
+        adata = AnnData.concatenate(
+            ref, adata, 
+            batch_categories=['reference', 'query'], 
+            batch_key='projection', 
+            index_unique=None
+        )
+        
+    if not ignore_umap:
+        sc.pp.neighbors(adata, n_neighbors=30, use_rep='latent')
+        sc.tl.umap(adata, min_dist=0.1)
+        sc.tl.leiden(adata)
         
         # UMAP visualization
         sc.settings.figdir = outdir
@@ -114,6 +137,10 @@ def SCALEX(data_list,
                 plot_umap(adata, cond1='projection', save='.pdf')
             else:
                 sc.pl.umap(adata, color=color, save='.pdf', wspace=0.4, ncols=4)
+
+    adata.write(outdir+'adata.h5ad', compression='gzip')
+        
+        
                 
 #                 if len(adata.obs['batch'].cat.categories) > 1:
 #                     entropy_score = entropy_batch_mixing(adata.obsm['X_umap'], adata.obs['batch'])
@@ -122,5 +149,4 @@ def SCALEX(data_list,
 #                 if 'celltype' in adata.obs:
 #                     sil_score = silhouette_score(adata.obsm['X_umap'], adata.obs['celltype'].cat.codes)
 #                     log.info("silhouette_score: {:.3f}".format(sil_score))
-                
-    return adata
+
