@@ -12,37 +12,23 @@ import scanpy as sc
 import matplotlib.pyplot as plt
 import seaborn as sns
 
-
-def plot_batch(adata, by='batch', name='celltype', color_map=None, batches=None, condition=None, savefig=None, 
-               legend_loc='right margin', legend_fontsize=None, legend_fontweight='bold'):
-    
-#     celltype_colors = dict(zip(result.obs['celltype'].cat.categories, result.uns['celltype_colors']))
-#     color_map = [celltype_colors[i] for i in subset.obs['celltype'].cat.categories]
-    if batches is None:
-        batches = adata.obs[by].cat.categories
-    for b in batches:
-        adata.obs['tmp'] = adata.obs[name].astype(str)
-        if condition is not None:
-            adata.obs['tmp'][~adata.obs[condition[0]].isin(condition[1])] = ''
-        adata.obs['tmp'][adata.obs[by]!=b] = ''
-        adata.obs['tmp'] = adata.obs['tmp'].astype('category')
-        if condition is not None:
-            groups = list(adata[(adata.obs[by]==b) & (adata.obs[condition[0]].isin(condition[1]))].obs[name].astype('category').cat.categories.values)
-        else:
-            groups = list(adata[adata.obs[by]==b].obs[name].astype('category').cat.categories.values)
-        if color_map is not None:
-            palette = [color_map[i] if i in color_map else 'gray' for i in adata.obs['tmp'].cat.categories]
-        else:
-            palette = None
-        size = min(40, 120000/len(adata[adata.obs[by]==b]))
-        sc.pl.umap(adata, color='tmp', groups=groups, title=b, palette=palette, size=size, 
-                   legend_loc=legend_loc, legend_fontsize=legend_fontsize, legend_fontweight=legend_fontweight)
-        del adata.obs['tmp']
-        
             
             
-def plot_umap(adata, color='celltype', color_map=None, cond1='batch', range1=None, cond2=None, v2=None, save=None, 
-               legend_loc='right margin', legend_fontsize=None, legend_fontweight='bold', sep='_', basis='umap'):
+def plot_umap(
+        adata, 
+        color='celltype', 
+        color_map=None, 
+        cond1='batch', 
+        range1=None, 
+        cond2=None, 
+        v2=None, 
+        save=None, 
+        legend_loc='right margin', 
+        legend_fontsize=None, 
+        legend_fontweight='bold', 
+        sep='_', 
+        basis='umap'
+    ):
     
 #     celltype_colors = dict(zip(result.obs['celltype'].cat.categories, result.uns['celltype_colors']))
 #     color_map = [celltype_colors[i] for i in subset.obs['celltype'].cat.categories]
@@ -94,7 +80,7 @@ def plot_legend(color_map, savefig=None, figsize=(0.1, 0.1), ncol=7, title=''):
         
 
 def plot_meta2(adata, use_rep='latent', var='celltype', batch='batch', color_map=None, figsize=(10, 10), cmap='Blues',
-              batches=None, annot=False, savefig=None, keep=False):
+              batches=None, annot=False, savefig=None, cbar=True, keep=False):
     """
     input: AnnData
     """
@@ -138,7 +124,7 @@ def plot_meta2(adata, use_rep='latent', var='celltype', batch='batch', color_map
 #         xticklabels, yticklabels = categories, categories
         xticklabels, yticklabels = [], []
     grid = sns.heatmap(corr, xticklabels=xticklabels, yticklabels=yticklabels, annot=annot,
-                cmap=cmap, square=True, cbar=False, vmin=0, vmax=1)
+                cmap=cmap, square=True, cbar=cbar, vmin=0, vmax=1)
 
     if color_map is not None:
         [ tick.set_color(color_map[tick.get_text()]) for tick in grid.get_xticklabels() ]
